=======
Insegel
=======

.. image:: http://scieldas.autophagy.io/rtd/insegel.png
    :target: http://insegel.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: http://scieldas.autophagy.io/pypi/version/insegel.png
   :target: https://pypi.python.org/pypi/insegel/
   :alt: Pypi Version

.. image:: http://scieldas.autophagy.io/pypi/pyversions/insegel.png
   :target: https://pypi.python.org/pypi/insegel/
   :alt: Python Version

.. image:: http://scieldas.autophagy.io/licenses/MIT.png
   :target: LICENSE
   :alt: MIT License

Insegel is a theme for `Sphinx`_, intended to unify my project documentation's
theme with that of `Hrǽw`_. The theme's documentation is available on
`ReadTheDocs`_.

.. image:: seonu/_static/screenshot.png
    :alt: aerende
    :align: center


.. _Sphinx: http://www.sphinx-doc.org/en/stable/
.. _Hrǽw: https://github.com/Autophagy/hraew
.. _ReadTheDocs: http://insegel.readthedocs.io
